abacusai.pipeline_version — AbacusAI documentation

# abacusai.pipeline_version

## Classes

`PipelineVersion` | A version of a pipeline.

## Module Contents

class abacusai.pipeline_version.PipelineVersion(client, pipelineName=None, pipelineId=None, pipelineVersion=None, createdAt=None, updatedAt=None, completedAt=None, status=None, error=None, stepVersions={}, codeSource={}, pipelineVariableMappings={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of a pipeline.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - pipelineName (str) – The name of the pipeline this step is a part of.

    - pipelineId (str) – The reference to the pipeline this step belongs to.

    - pipelineVersion (str) – The reference to this pipeline version.

    - createdAt (str) – The date and time which this pipeline version was created.

    - updatedAt (str) – The date and time which this pipeline version was updated.

    - completedAt (str) – The date and time which this pipeline version was updated.

    - status (str) – The status of the pipeline version.

    - error (str) – The relevant error, if the status is FAILED.

    - stepVersions (PipelineStepVersion) – A list of the pipeline step versions.

    - codeSource (CodeSource) – information on the source code

    - pipelineVariableMappings (PythonFunctionArgument) – A description of the function variables into the pipeline.

  pipeline_name = None
  pipeline_id = None
  pipeline_version = None
  created_at = None
  updated_at = None
  completed_at = None
  status = None
  error = None
  step_versions
  code_source
  pipeline_variable_mappings
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      PipelineVersion

  describe()

    Describes a specified pipeline version

    Parameters:

      pipeline_version (str) – Unique string identifier for the pipeline version

    Returns:

      Object describing the pipeline version

    Return type:

      PipelineVersion

  reset(steps=None, include_downstream_steps=True)

    Reruns a pipeline version for the given steps and downstream steps if specified.

    Parameters:

      - steps (list) – List of pipeline step names to rerun.

      - include_downstream_steps (bool) – Whether to rerun downstream steps from the steps you have passed

    Returns:

      Object describing the pipeline version

    Return type:

      PipelineVersion

  list_logs()

    Gets the logs for the steps in a given pipeline version.

    Parameters:

      pipeline_version (str) – The id of the pipeline version.

    Returns:

      Object describing the logs for the steps in the pipeline.

    Return type:

      PipelineVersionLogs

  skip_pending_steps()

    Skips pending steps in a pipeline version.

    Parameters:

      pipeline_version (str) – The id of the pipeline version.

    Returns:

      Object describing the pipeline version

    Return type:

      PipelineVersion

  wait_for_pipeline(timeout=1200)

    A waiting call until all the stages in a pipeline version have completed.

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the pipeline version.

    Returns:

      A string describing the status of a pipeline version (pending, running, complete, etc.).

    Return type:

      str